@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
@@ -274,9 +274,6 @@ void bugs::expired_pwd()
 {
   logMsg("bugs::expired_pwd");
 
-  //TODO: Enable it after fixing
-  SKIP("Removed untill fixed");
-
   if (getMySQLVersion(con) < 56006)
   {
     SKIP("The server does not support tested functionality(expired password)");
@@ -294,7 +291,7 @@ void bugs::expired_pwd()
   }
 
   stmt->executeUpdate("CREATE USER ccpp_expired_pwd IDENTIFIED BY 'foo'");
-  stmt->executeUpdate("GRANT ALL ON test to ccpp_expired_pwd");
+  stmt->executeUpdate("GRANT ALL ON test.* to ccpp_expired_pwd");
   stmt->executeUpdate("ALTER USER ccpp_expired_pwd PASSWORD EXPIRE");
 
   sql::ConnectOptionsMap opts;
@@ -309,7 +306,7 @@ void bugs::expired_pwd()
       SKIP("The expired password does not work with anonymous-user accounts.");
     }
   }
-  catch (sql::SQLException &e)
+  catch (sql::SQLException&)
   {
     /* If no anonymous user present then continue */
   }
@@ -345,7 +342,12 @@ void bugs::expired_pwd()
   }
 
   // Now setting new password and getting fully functional connection
-  opts["preInit"]= sql::SQLString("set password= password('bar')");
+  if (getMySQLVersion(con) < 57006)
+    opts["preInit"]= sql::SQLString("set password= password('bar')");
+  else
+    opts["preInit"]= sql::SQLString("ALTER USER 'ccpp_expired_pwd' IDENTIFIED BY 'bar';");
+
+
 
   // Connect should go thru fine
   try
@@ -493,9 +495,6 @@ void bugs::bug71606()
 {
   logMsg("bugs::bug71606");
 
-  //TODO: Enable it after fixing
-  SKIP("Removed untill fixed");
-
   if (getMySQLVersion(con) < 56000)
   {
     SKIP("The server does not support tested functionality(utf8mb4 charset)");
@@ -887,7 +886,7 @@ void bugs::bug21053335()
       ASSERT(res->wasNull());
       FAIL("Exception was not thrown by wasNull()");
     }
-    catch (sql::SQLException & e)
+    catch (sql::SQLException&)
     {
       // Everything is ok
     }
@@ -902,7 +901,7 @@ void bugs::bug21053335()
 
   }
 
-  catch (sql::SQLException &e)
+  catch (sql::SQLException&)
   {
     FAIL("Exception thrown by wasNull()");
     throw;
@@ -938,7 +937,7 @@ void bugs::bug17218692()
     ASSERT_EQUALS(log.str(), log2.str());
 
   }
-  catch (sql::SQLException & e)
+  catch (sql::SQLException&)
   {
     FAIL("Exception thrown");
     throw;
@@ -969,7 +968,7 @@ void bugs::bug21067193()
     ASSERT_EQUALS(false, res->absolute(std::numeric_limits<int>::min())); //Invalid position, Returns FALSE
 
   }
-  catch (sql::SQLException & e)
+  catch (sql::SQLException&)
   {
 //	Error....
       throw;
@@ -1093,5 +1092,22 @@ void bugs::bug17227390()
   }
 }
 
+/* Bug #28204677 - The driver defaults to utf8mb4 */
+void bugs::bug28204677()
+{
+  logMsg("bugs::bug71606");
+
+  if (getMySQLVersion(con) < 57000)
+  {
+    SKIP("The server does not support tested functionality(default utf8mb4 charset)");
+  }
+
+  res.reset(stmt->executeQuery("SHOW VARIABLES like 'character_set_client'"));
+  res->next();
+
+  ASSERT_EQUALS(res->getString(2),"utf8mb4");
+}
+
 } /* namespace regression */
 } /* namespace testsuite */
+
