@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
@@ -577,7 +577,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception I");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -591,7 +591,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception II");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -605,7 +605,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception III");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -619,7 +619,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception IV");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -632,7 +632,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception V");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -645,7 +645,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception VI");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -658,7 +658,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception VII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -671,7 +671,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception VIII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -684,7 +684,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception IX");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -697,7 +697,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception X");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -710,7 +710,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XI");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -723,7 +723,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -736,7 +736,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XIII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -751,7 +751,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XIV");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       expected
     }
@@ -765,7 +765,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XV");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -778,7 +778,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XVI");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -791,7 +791,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XVII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -804,7 +804,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XVIII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -817,7 +817,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XIX");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -830,7 +830,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XX");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -843,7 +843,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXI");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -856,7 +856,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -869,7 +869,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXIII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -882,7 +882,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXIV");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -895,7 +895,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXV");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -908,7 +908,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXVI");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -921,7 +921,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXVII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -934,7 +934,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXVIII");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -947,7 +947,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXIX");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -960,7 +960,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXX");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -973,7 +973,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXXI - sslVerify");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -986,7 +986,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXXII - sslCRL");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -999,7 +999,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXXIII - sslCRLPath");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -1012,7 +1012,7 @@ void connection::connectUsingMapWrongTypes()
       con.reset(driver->connect(connection_properties));
       FAIL("No exception XXXIII - rsaKey");
     }
-    catch (sql::InvalidArgumentException)
+    catch (sql::InvalidArgumentException&)
     {
       /* expected */
     }
@@ -2912,7 +2912,7 @@ void connection::reconnect()
       res.reset(stmt->executeQuery("SELECT sleep(10);"));
       FAIL("Connection didn't timed out");
     }
-    catch (sql::SQLException /*&e*/)
+    catch (sql::SQLException &/*e*/)
     {
       ASSERT(con->reconnect());
       res.reset(stmt->executeQuery("SELECT 1;"));
@@ -2950,7 +2950,7 @@ void connection::reconnect()
       res.reset(stmt->executeQuery("SELECT sleep(10);"));
       FAIL("Connection didn't timed out");
     }
-    catch (sql::SQLException /*&e*/)
+    catch (sql::SQLException &/*e*/)
     {
       ASSERT(con->reconnect());
       res.reset(stmt->executeQuery("SELECT 1;"));
@@ -3102,7 +3102,7 @@ void connection::tls_version()
     con.reset(driver->connect(connection_properties));
     FAIL("Wrong TLS version used and still can connect!");
   }
-  catch (sql::SQLException &e)
+  catch (sql::SQLException &)
   {
     //Should FAIL to connect
   }
